==> moodle-1.4.3-pgsql.tgz: moodle/lang/nl/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['addanewdiscussion'] = 'Voeg een nieuw onderwerp voor discussie toe';
$string['addanewtopic'] = 'Voeg een nieuw onderwerp toe';
$string['allowchoice'] = 'Sta iedereen toe om te kiezen';
$string['allowdiscussions'] = 'Mag een $a berichten posten?';
$string['allowratings'] = 'Mogen berichten beoordeeld worden?';
$string['allowsdiscussions'] = 'In dit forum mag iedereen precies n discussie starten.';
$string['anyfile'] = 'Een bestand';
$string['attachment'] = 'Bijlage';
$string['bynameondate'] = 'door  $a->name  - $a->date';
$string['configdisplaymode'] = 'De standaardmanier voor het weergeven van discussies als er geen methode is ingesteld.';
$string['configenablerssfeeds'] = 'Met deze instelling kun je de mogelijkheid voor het maken van RSS-feeds inschakelen voor alle forums. Je zult wel nog voor elk forum afzonderlijk het maken van de RSS-feeds moeten  inschakelen. ';
$string['configlongpost'] = 'Elk bericht dat langer is dan deze waarde (HTML-code niet inbegrepen) wordt als lang beschouwd.';
$string['configmanydiscussions'] = 'Maximale aantal discussies van een forum die per pagina getoond worden';
$string['configmaxbytes'] = 'Standaard maximumgrootte voor alle forum bijlagen op deze site (afhankelijk van vaklimieten en andere lokale instellingen)';
$string['configreplytouser'] = 'Wil je dat de e-mail van een bericht op het forum het e-mailadres van de verstuurder bevat, zodat de ontvangers eventueel ook persoonlijk kunnen antwoorden, eerder dan via het forum? Zelfs als je hier \'Ja\' instelt, kunnen gebruikers ervoor kiezen hun e-mailadres priv te houden via hun profielpagina';
$string['configshortpost'] = 'Elk bericht dat korter is dan deze waarde (HTML-code niet inbegrepen) wordt als kort beschouwd.';
$string['couldnotadd'] = 'Door een onbekende fout was het niet mogelijk om je bericht toe te voegen .';
$string['couldnotdeleteratings'] = 'Helaas, dit kan niet worden verwijderd omdat iemand het bericht al beoordeeld heeft';
$string['couldnotdeletereplies'] = 'Helaas, dit kan niet worden verwijderd omdat er al op geantwoord is.';
$string['couldnotupdate'] = 'Kon je bericht niet bijwerken door een onbekende fout.';
$string['delete'] = 'Verwijder';
$string['deleteddiscussion'] = 'De discussie is verwijderd';
$string['deletedpost'] = 'De bijdrage is verwijderd';
$string['deletesure'] = 'Weet je zeker dat je dit bericht wilt verwijderen?';
$string['digestmailheader'] = 'Dit is je dagelijkse samenvattende e-mail met de nieuwe berichten van de forums van $a->sitename. Als je jouw voorkeurinstellingen voor de e-maildienst van de forums wil wijzigen, ga dan naar $a->userprefs.';
$string['digestmailprefs'] = 'Jouw gebruikersprofiel';
$string['digestmailsubject'] = 'Dagelijkse forumsamenvatting van $a';
$string['digestsentusers'] = 'Samenvattende e-mail met succes naar $a gebruikers gestuurd.';
$string['discussion'] = 'Discussie';
$string['discussionmoved'] = 'Deze discussie is verplaatst naar \'$a\'.';
$string['discussionname'] = 'Discussienaam';
$string['discussions'] = 'Discussies';
$string['discussionsstartedby'] = 'Discussies die door $a zijn gestart';
$string['discussionsstartedbyrecent'] = 'Discussies die recentelijk door $a zijn gestart';
$string['discussthistopic'] = 'Draag bij aan de discussie';
$string['eachuserforum'] = 'Iedereen voegt n discussie toe';
$string['edit'] = 'Wijzig';
$string['editing'] = 'Wijzigen';
$string['emptymessage'] = 'Er was iets mis met je bericht. Misschien heb je het leeg gelaten of was de bijlage te groot. Je wijzigingen zijn NIET bewaard.';
$string['everyonecanchoose'] = 'Iedereen kan kiezen om al dan niet lid te zijn.';
$string['everyoneissubscribed'] = 'Iedereen is lid van dit forum';
$string['existingsubscribers'] = 'Huidige leden';
$string['forcesubscribe'] = 'Verplicht iedereen om lid te zijn';
$string['forcesubscribeq'] = 'Moet iedereen verplicht lid zijn?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'De inleiding van het forum';
$string['forumname'] = 'Naam van het forum';
$string['forums'] = 'Forums';
$string['forumtype'] = 'Soort forum';
$string['generalforum'] = 'Standaardforum voor algemeen gebruik ';
$string['generalforums'] = 'Algemene forums';
$string['inforum'] = 'in $a';
$string['intronews'] = 'Algemeen nieuws en aankondigingen';
$string['introsocial'] = 'Een open forum om te chatten over wat je maar wilt';
$string['introteacher'] = 'Een forum alleen bestemd voor discussies en aantekeningen van leraren';
$string['lastpost'] = 'Laatste bericht';
$string['learningforums'] = 'Leerforums';
$string['maxattachmentsize'] = 'Maximum grootte van bijlagen';
$string['maxtimehaspassed'] = 'Helaas is de maximale tijd voor het wijzigen van dit bericht ($a) verstreken!';
$string['message'] = 'Bericht';
$string['modeflatnewestfirst'] = 'Laat de antwoorden in n lijst zien, met de nieuwste eerst';
$string['modeflatoldestfirst'] = 'Laat de antwoorden in n lijst zien, met de oudste eerst';
$string['modenested'] = 'Laat de antwoorden \'genest\' zien';
$string['modethreaded'] = 'Laat de antwoorden in hun \'draden\' zien';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forums';
$string['more'] = 'meer';
$string['movethisdiscussionto'] = 'Verplaats deze discussie naar ...';
$string['namenews'] = 'Nieuwsforum';
$string['namesocial'] = 'Sociaal forum';
$string['nameteacher'] = 'Forum voor leraren';
$string['newforumposts'] = 'Nieuwe forumberichten';
$string['nodiscussions'] = 'Er zijn nog geen discussies in dit forum';
$string['noguestpost'] = 'Sorry, gasten mogen geen berichten posten';
$string['nomorepostscontaining'] = 'Er zijn geen berichten met \'$a\' meer gevonden';
$string['nonews'] = 'Er zijn nog geen nieuwsberichten';
$string['noposts'] = 'Geen berichten';
$string['nopostscontaining'] = 'Er zijn geen berichten met \'$a\' gevonden';
$string['nosubscribers'] = 'Er is nog niemand lid van dit forum';
$string['notingroup'] = 'Sorry, je moet bij een groep horen om dit forum te kunnen zien.';
$string['nownotsubscribed'] = '$a->name zal via e-mail GEEN bijdragen aan \'$a->forum\' ontvangen.';
$string['nowsubscribed'] = '$a->naam zal bijdragen aan \'$a->forum\' ontvangen via e-mail.';
$string['numposts'] = '$a berichten';
$string['olderdiscussions'] = 'Oudere discussies';
$string['openmode0'] = 'Geen nieuwe discussies, geen antwoorden';
$string['openmode1'] = 'Geen nieuwe discussies mogelijk, maar antwoorden is toegestaan';
$string['openmode2'] = 'Nieuwe discussies en antwoorden zijn toegestaan';
$string['parent'] = 'Toon discussiestart';
$string['parentofthispost'] = 'Discussiestart van dit bericht';
$string['postadded'] = 'Je bericht is gepost.<p> Je hebt $a de tijd om dit bericht te wijzigen als je nog iets wilt veranderen.';
$string['postincontext'] = 'Bekijk dit bericht in zijn context';
$string['postmailinfo'] = 'Dit is een kopie van een bericht dat op de $a website is toegevoegd.

Klik op deze link om jouw antwoord via de website toe te voegen:';
$string['postrating1'] = 'Vooral \'Separate Knowing\'';
$string['postrating2'] = '\'Separate\'en \'Knowing\'';
$string['postrating3'] = 'Vooral \'Connected\'';
$string['posts'] = 'Berichten';
$string['posttoforum'] = 'Plaats op het forum';
$string['postupdated'] = 'Je bericht is bijgewerkt';
$string['potentialsubscribers'] = 'Mogelijke leden';
$string['processingdigest'] = 'E-mailsamenvatting aan het verwerken voor gebruiker $a';
$string['processingpost'] = 'Bericht $a aan het verwerken';
$string['prune'] = 'Splits discussie';
$string['prunedpost'] = 'Er is een nieuwe discussie gestart met dat bericht';
$string['pruneheading'] = 'Splits deze discussie en begin met dit bericht een nieuwe discussie';
$string['rate'] = 'Beoordeel';
$string['rating'] = 'Beoordeling';
$string['ratingeveryone'] = 'Iedereen kan berichten beoordelen';
$string['ratingno'] = 'Geen beoordelingen';
$string['ratingonlyteachers'] = 'Alleen $a kunnen berichten beoordelen';
$string['ratingpublic'] = '$a kunnen ieders beoordelingen zien';
$string['ratingpublicnot'] = '$a kunnen alleen hun eigen beoordelingen zien';
$string['ratings'] = 'Beoordelingen ';
$string['ratingssaved'] = 'Beoordelingen zijn bewaard';
$string['ratingsuse'] = 'Gebruik beoordelingen';
$string['ratingtime'] = 'Beperk het beoordelen van berichten tot het bereik van deze data:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Lees de rest van deze discussie';
$string['replies'] = 'Antwoorden';
$string['repliesmany'] = '$a antwoorden tot nu toe';
$string['repliesone'] = '$a antwoord tot nu toe';
$string['reply'] = 'Antwoord';
$string['replyforum'] = 'Antwoord op het forum';
$string['rsssubscriberssdiscussions'] = 'Met deze link kun je inschrijven op het \'$a\' forum RSS-discussiekanaal';
$string['rsssubscriberssposts'] = 'Met deze link kun je inschrijven op het \'$a\' forum RSS-postkanaal';
$string['search'] = 'Zoek';
$string['searchforums'] = 'Zoeken in forums';
$string['searcholderposts'] = 'Doorzoek oudere berichten...';
$string['searchresults'] = 'Zoekresultaten';
$string['sendinratings'] = 'Bewaar mijn beoordelingen';
$string['showsubscribers'] = 'Toon / wijzig leden';
$string['singleforum'] = 'En eenvoudige discussie';
$string['startedby'] = 'Begonnen door';
$string['subject'] = 'Onderwerp  ';
$string['subscribe'] = 'Wordt lid van dit forum';
$string['subscribeall'] = 'Maak alle deelnemers van het vak lid van dit forum';
$string['subscribed'] = 'Lid';
$string['subscribenone'] = 'Zeg lidmaatschap van alle leden van dit forum op';
$string['subscribers'] = 'Leden';
$string['subscribersto'] = 'Leden van \'$a\'';
$string['subscribestart'] = 'Stuur me een kopie per e-mail wanneer iemand post op dit forum';
$string['subscribestop'] = 'Ik wil geen kopie van inzendingen op dit forum per e-mail ontvangen';
$string['subscription'] = 'Lid worden';
$string['subscriptions'] = 'Inschrijvingen';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Nederlands';
$string['unsubscribe'] = 'Zeg het lidmaatschap van dit forum op';
$string['unsubscribed'] = 'Lidmaatschap opgezegd';
$string['unsubscribeshort'] = 'Lidmaatschap opzeggen';
$string['yesforever'] = 'Ja, voor altijd';
$string['yesinitially'] = 'Ja, initieel';
$string['youratedthis'] = 'Je beoordeelde dit';
$string['yournewtopic'] = 'Je nieuwe discussie onderwerp';
$string['yourreply'] = 'Jouw antwoord';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/nl/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 ALPHA (2005042400)


$string['addanewdiscussion'] = 'Voeg een nieuw onderwerp voor discussie toe';
$string['addanewtopic'] = 'Voeg een nieuw onderwerp toe';
$string['advancedsearch'] = 'Uitgebreid zoeken';
$string['allforums'] = 'Alle forums';
$string['allowchoice'] = 'Sta iedereen toe om te kiezen';
$string['allowdiscussions'] = 'Mag een $a berichten posten?';
$string['allowratings'] = 'Mogen berichten beoordeeld worden?';
$string['allowsdiscussions'] = 'In dit forum mag iedereen precies n discussie starten.';
$string['anyfile'] = 'Een bestand';
$string['attachment'] = 'Bijlage';
$string['bynameondate'] = 'door  $a->name  - $a->date';
$string['configcleanreadtime'] = 'Het uur van de dag waarop oude post van de \'gelezen\' -tabel moeten verwijderd worden.';
$string['configdisplaymode'] = 'De standaardmanier voor het weergeven van discussies als er geen methode is ingesteld.';
$string['configenablerssfeeds'] = 'Met deze instelling kun je de mogelijkheid voor het maken van RSS-feeds inschakelen voor alle forums. Je zult wel nog voor elk forum afzonderlijk het maken van de RSS-feeds moeten  inschakelen. ';
$string['configlongpost'] = 'Elk bericht dat langer is dan deze waarde (HTML-code niet inbegrepen) wordt als lang beschouwd.';
$string['configmanydiscussions'] = 'Maximale aantal discussies van een forum die per pagina getoond worden';
$string['configmaxbytes'] = 'Standaard maximumgrootte voor alle forumbijlagen op deze site (afhankelijk van vaklimieten en andere lokale instellingen)';
$string['configoldpostdays'] = 'Aantal dagen waarna elk bericht als gelezen moet beschouwd worden.';
$string['configreplytouser'] = 'Wil je dat de e-mail van een bericht op het forum het e-mailadres van de verstuurder bevat, zodat de ontvangers eventueel ook persoonlijk kunnen antwoorden, eerder dan via het forum? Zelfs als je hier \'Ja\' instelt, kunnen gebruikers ervoor kiezen hun e-mailadres priv te houden via hun profielpagina';
$string['configshortpost'] = 'Elk bericht dat korter is dan deze waarde (HTML-code niet inbegrepen) wordt als kort beschouwd.';
$string['configtrackreadposts'] = 'Zet op \'ja\' als je gelezen/niet gelezen wil bijhouden voor elke gebruiker.';
$string['configusermarksread'] = 'Indien \'ja\' moet de lezer de berichten manueel als gelezen markeren. Indien \'nee\' wordt het bericht als gelezen gemarkeerd wanneer het geopend werd.';
$string['couldnotadd'] = 'Door een onbekende fout was het niet mogelijk om je bericht toe te voegen .';
$string['couldnotdeleteratings'] = 'Helaas, dit kan niet worden verwijderd omdat iemand het bericht al beoordeeld heeft';
$string['couldnotdeletereplies'] = 'Helaas, dit kan niet worden verwijderd omdat er al op geantwoord is.';
$string['couldnotupdate'] = 'Kon je bericht niet bijwerken door een onbekende fout.';
$string['delete'] = 'Verwijder';
$string['deleteddiscussion'] = 'De discussie is verwijderd';
$string['deletedpost'] = 'De bijdrage is verwijderd';
$string['deletedposts'] = 'Deze berichten werden verwijderd';
$string['deletesure'] = 'Weet je zeker dat je dit bericht wilt verwijderen?';
$string['deletesureplural'] = 'Weet je zeker dat je dit bericht en alle antwoorden erop wil verwijderen? ($a berichten)';
$string['digestmailheader'] = 'Dit is je dagelijkse samenvattende e-mail met de nieuwe berichten van de forums van $a->sitename. Als je jouw voorkeurinstellingen voor de e-maildienst van de forums wil wijzigen, ga dan naar $a->userprefs.';
$string['digestmailprefs'] = 'Jouw gebruikersprofiel';
$string['digestmailsubject'] = 'Dagelijkse forumsamenvatting van $a';
$string['digestsentusers'] = 'Samenvattende e-mail met succes naar $a gebruikers gestuurd.';
$string['discussion'] = 'Discussie';
$string['discussionmoved'] = 'Deze discussie is verplaatst naar \'$a\'.';
$string['discussionname'] = 'Discussienaam';
$string['discussions'] = 'Discussies';
$string['discussionsstartedby'] = 'Discussies die door $a zijn gestart';
$string['discussionsstartedbyrecent'] = 'Discussies die recentelijk door $a zijn gestart';
$string['discussthistopic'] = 'Draag bij aan de discussie';
$string['eachuserforum'] = 'Iedereen voegt n discussie toe';
$string['edit'] = 'Wijzig';
$string['editedby'] = 'Bewerkt door $s->name - $a->date';
$string['editing'] = 'Wijzigen';
$string['emptymessage'] = 'Er was iets mis met je bericht. Misschien heb je het leeg gelaten of was de bijlage te groot. Je wijzigingen zijn NIET bewaard.';
$string['everyonecanchoose'] = 'Iedereen kan kiezen om al dan niet lid te zijn.';
$string['everyoneissubscribed'] = 'Iedereen is lid van dit forum';
$string['existingsubscribers'] = 'Huidige leden';
$string['forcesubscribe'] = 'Verplicht iedereen om lid te zijn';
$string['forcesubscribeq'] = 'Moet iedereen verplicht lid zijn?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'De inleiding van het forum';
$string['forumname'] = 'Naam van het forum';
$string['forumposts'] = 'Forumberichten';
$string['forums'] = 'Forums';
$string['forumtype'] = 'Soort forum';
$string['generalforum'] = 'Standaardforum voor algemeen gebruik ';
$string['generalforums'] = 'Algemene forums';
$string['inforum'] = 'in $a';
$string['intronews'] = 'Algemeen nieuws en aankondigingen';
$string['introsocial'] = 'Een open forum om te chatten over wat je maar wilt';
$string['introteacher'] = 'Een forum alleen bestemd voor discussies en aantekeningen van leraren';
$string['lastpost'] = 'Laatste bericht';
$string['learningforums'] = 'Leerforums';
$string['markalldread'] = 'Markeer alle berichten in deze discussie als gelezen';
$string['markallread'] = 'Markeer alle berichten in dit forum als gelezen';
$string['markread'] = 'Markeer als gelezen';
$string['markreadbutton'] = 'Markeer als<br />gelezen';
$string['markunread'] = 'Markeer als niet gelezen';
$string['markunreadbutton'] = 'Markeer als<br />niet gelezen';
$string['maxattachmentsize'] = 'Maximum grootte van bijlagen';
$string['maxtimehaspassed'] = 'Helaas is de maximale tijd voor het wijzigen van dit bericht ($a) verstreken!';
$string['message'] = 'Bericht';
$string['missingsearchterms'] = 'Volgende zoektermen komen alleen in de HTML-opmaak van deze boodschap voor:';
$string['modeflatnewestfirst'] = 'Laat de antwoorden in n lijst zien, met de nieuwste eerst';
$string['modeflatoldestfirst'] = 'Laat de antwoorden in n lijst zien, met de oudste eerst';
$string['modenested'] = 'Laat de antwoorden \'genest\' zien';
$string['modethreaded'] = 'Laat de antwoorden in hun \'draden\' zien';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forums';
$string['more'] = 'meer';
$string['movethisdiscussionto'] = 'Verplaats deze discussie naar ...';
$string['namenews'] = 'Nieuwsforum';
$string['namesocial'] = 'Sociaal forum';
$string['nameteacher'] = 'Forum voor leraren';
$string['newforumposts'] = 'Nieuwe forumberichten';
$string['nodiscussions'] = 'Er zijn nog geen discussies in dit forum';
$string['noguestpost'] = 'Sorry, gasten mogen geen berichten posten';
$string['noguestsubscribe'] = 'Sorry, gasten mogen zich niet inschrijven om forumberichten via mail te kunnen ontvangen.';
$string['noguesttracking'] = 'Sorry, gasten kunnen de instellingen voor het opvolgen van forumberichten niet wijzigen.';
$string['nomorepostscontaining'] = 'Er zijn geen berichten met \'$a\' meer gevonden';
$string['nonews'] = 'Er zijn nog geen nieuwsberichten';
$string['noposts'] = 'Geen berichten';
$string['nopostscontaining'] = 'Er zijn geen berichten met \'$a\' gevonden';
$string['nosubscribers'] = 'Er is nog niemand lid van dit forum';
$string['notingroup'] = 'Sorry, je moet bij een groep horen om dit forum te kunnen zien.';
$string['notrackforum'] = 'Schakel opvolgen van ongelezen berichten uit';
$string['nownotsubscribed'] = '$a->name zal via e-mail GEEN bijdragen aan \'$a->forum\' ontvangen.';
$string['nownottracking'] = '$a->name volgt niet langer het forum \'$a->forum\'.';
$string['nowsubscribed'] = '$a->naam zal bijdragen aan \'$a->forum\' ontvangen via e-mail.';
$string['nowtracking'] = '$a->name volgt nu het forum \'$a->forum\'.';
$string['numposts'] = '$a berichten';
$string['olderdiscussions'] = 'Oudere discussies';
$string['oldertopics'] = 'Oudere onderwerpen';
$string['openmode0'] = 'Geen nieuwe discussies, geen antwoorden';
$string['openmode1'] = 'Geen nieuwe discussies mogelijk, maar antwoorden zijn toegestaan';
$string['openmode2'] = 'Nieuwe discussies en antwoorden zijn toegestaan';
$string['parent'] = 'Toon discussiestart';
$string['parentofthispost'] = 'Discussiestart van dit bericht';
$string['postadded'] = 'Je bericht is gepost.<p> Je hebt $a de tijd om dit bericht te wijzigen als je nog iets wilt veranderen.';
$string['postincontext'] = 'Bekijk dit bericht in zijn context';
$string['postmailinfo'] = 'Dit is een kopie van een bericht dat op de $a website is toegevoegd.

Klik op deze link om jouw antwoord via de website toe te voegen:';
$string['postrating1'] = 'Vooral \'Separate Knowing\'';
$string['postrating2'] = '\'Separate\'en \'Knowing\'';
$string['postrating3'] = 'Vooral \'Connected\'';
$string['posts'] = 'Berichten';
$string['posttoforum'] = 'Plaats op het forum';
$string['postupdated'] = 'Je bericht is bijgewerkt';
$string['potentialsubscribers'] = 'Mogelijke leden';
$string['processingdigest'] = 'E-mailsamenvatting aan het verwerken voor gebruiker $a';
$string['processingpost'] = 'Bericht $a aan het verwerken';
$string['prune'] = 'Splits discussie';
$string['prunedpost'] = 'Er is een nieuwe discussie gestart met dat bericht';
$string['pruneheading'] = 'Splits deze discussie en begin met dit bericht een nieuwe discussie';
$string['rate'] = 'Beoordeel';
$string['rating'] = 'Beoordeling';
$string['ratingeveryone'] = 'Iedereen kan berichten beoordelen';
$string['ratingno'] = 'Geen beoordelingen';
$string['ratingonlyteachers'] = 'Alleen $a kunnen berichten beoordelen';
$string['ratingpublic'] = '$a kunnen ieders beoordelingen zien';
$string['ratingpublicnot'] = '$a kunnen alleen hun eigen beoordelingen zien';
$string['ratings'] = 'Beoordelingen ';
$string['ratingssaved'] = 'Beoordelingen zijn bewaard';
$string['ratingsuse'] = 'Gebruik beoordelingen';
$string['ratingtime'] = 'Beperk het beoordelen van berichten tot het bereik van deze data:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Lees de rest van deze discussie';
$string['replies'] = 'Antwoorden';
$string['repliesmany'] = '$a antwoorden tot nu toe';
$string['repliesone'] = '$a antwoord tot nu toe';
$string['reply'] = 'Antwoord';
$string['replyforum'] = 'Antwoord op het forum';
$string['rsssubscriberssdiscussions'] = 'Met deze link kun je inschrijven op het \'$a\' forum RSS-discussiekanaal';
$string['rsssubscriberssposts'] = 'Met deze link kun je inschrijven op het \'$a\' forum RSS-postkanaal';
$string['search'] = 'Zoek';
$string['searchdatefrom'] = 'Berichten nieuwer dan dit';
$string['searchdateto'] = 'Berichten ouder dan dit';
$string['searchforumintro'] = 'Geef zoekwoorden in n of meer van volgende velden:';
$string['searchforums'] = 'Zoeken in forums';
$string['searchfullwords'] = 'Deze woorden moeten als volledige woorden voorkomen';
$string['searchnotwords'] = 'Deze woorden mogen NIET voorkomen';
$string['searcholderposts'] = 'Doorzoek oudere berichten...';
$string['searchphrase'] = 'Dit zinsdeel moet exact voorkomen in het bericht';
$string['searchresults'] = 'Zoekresultaten';
$string['searchsubject'] = 'Deze woorden moeten in het onderwerp staan';
$string['searchuser'] = 'Dit is de naam van de auteur';
$string['searchuserid'] = 'Dit is de Moodle ID van de auteur';
$string['searchwhichforums'] = 'Kies in welke forums je wil zoeken';
$string['searchwords'] = 'Deze woorden mogen overal in het bericht voorkomen';
$string['seeallposts'] = 'Bekijk alle berichten die deze gebruiker gepost heeft';
$string['sendinratings'] = 'Bewaar mijn beoordelingen';
$string['showsubscribers'] = 'Toon / wijzig leden';
$string['singleforum'] = 'En eenvoudige discussie';
$string['startedby'] = 'Begonnen door';
$string['subject'] = 'Onderwerp  ';
$string['subscribe'] = 'Wordt lid van dit forum';
$string['subscribeall'] = 'Maak alle deelnemers van de cursus lid van dit forum';
$string['subscribed'] = 'Lid';
$string['subscribenone'] = 'Zeg lidmaatschap van alle leden van dit forum op';
$string['subscribers'] = 'Leden';
$string['subscribersto'] = 'Leden van \'$a\'';
$string['subscribestart'] = 'Stuur me een kopie per e-mail wanneer iemand post op dit forum';
$string['subscribestop'] = 'Ik wil geen kopie van inzendingen op dit forum per e-mail ontvangen';
$string['subscription'] = 'Lid worden';
$string['subscriptions'] = 'Inschrijvingen';
$string['trackforum'] = 'Volg ongelezen berichten op';
$string['tracking'] = 'Opvolgen';
$string['trackingoff'] = 'Uit';
$string['trackingon'] = 'Aan';
$string['trackingoptional'] = 'Optioneel';
$string['trackingtype'] = 'Lezen van dit forum opvolgen?';
$string['unread'] = 'Niet gelezen';
$string['unreadposts'] = 'Niet gelezen berichten';
$string['unreadpostsnumber'] = '$a berichten niet gelezen';
$string['unreadpostsone'] = '1 bericht niet gelezen';
$string['unsubscribe'] = 'Zeg het lidmaatschap van dit forum op';
$string['unsubscribed'] = 'Lidmaatschap opgezegd';
$string['unsubscribeshort'] = 'Lidmaatschap opzeggen';
$string['yesforever'] = 'Ja, voor altijd';
$string['yesinitially'] = 'Ja, initieel';
$string['youratedthis'] = 'Je beoordeelde dit';
$string['yournewtopic'] = 'Je nieuwe discussieonderwerp';
$string['yourreply'] = 'Jouw antwoord';

?>
